Module
------------------------

.. automodule:: flax.linen
.. currentmodule:: flax.linen

.. autoclass:: Module
   :members: setup, variable, param, bind, unbind, apply, init, init_with_output, make_rng, sow, variables, Variable, __setattr__, tabulate, is_initializing, perturb